```{caution}
This API is not finalised, and may change in a patch version.
```

# `installer.scripts`

Provides the ability to generate executable launcher scripts, that are based on
[`simple_launcher`]. A description of how these scripts work is available in
simple_launcher's README.

[`simple_launcher`]: https://bitbucket.org/vinay.sajip/simple_launcher/

```{eval-rst}
.. autoclass:: installer.scripts.InvalidScript()

.. autoclass:: installer.scripts.Script()
    :special-members: __init__
    :members:
```
